"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeFadeIn = makeFadeIn;
exports.makeFadeLeft = makeFadeLeft;
exports.makeFadeRight = makeFadeRight;
exports.makeFadeDown = makeFadeDown;
exports.makeFadeUp = makeFadeUp;

/**
 * @public
 * @name makeFadeIn
 * @description make fade in object
 * @returns {{0%: {opacity: number}, 100%: {opacity: number}}}
 */
function makeFadeIn() {
  return {
    '0%': {
      opacity: 0
    },
    '100%': {
      opacity: 1
    }
  };
}
/**
 * @public
 * @name makeFadeLeft
 * @description make fade left object
 * @param distance
 * @returns {{from: {opacity: number, transform: string}, to: {opacity: number, transform: string}}}
 */


function makeFadeLeft(_ref) {
  var distance = _ref.distance;
  return {
    from: {
      opacity: 0,
      transform: "translate3d(-".concat(distance, ", 0, 0)")
    },
    to: {
      opacity: 1,
      transform: 'none'
    }
  };
}
/**
 * @public
 * @name makeFadeRight
 * @description make fade right object
 * @param distance
 * @returns {{from: {opacity: number, transform: string}, to: {opacity: number, transform: string}}}
 */


function makeFadeRight(_ref2) {
  var distance = _ref2.distance;
  return {
    from: {
      opacity: 0,
      transform: "translate3d(".concat(distance, ", 0, 0)")
    },
    to: {
      opacity: 1,
      transform: 'none'
    }
  };
}
/**
 * @public
 * @name makeFadeDown
 * @description make fade down object
 * @param distance
 * @returns {{from: {opacity: number, transform: string}, to: {opacity: number, transform: string}}}
 */


function makeFadeDown(_ref3) {
  var distance = _ref3.distance;
  return {
    from: {
      opacity: 0,
      transform: "translate3d(0, -".concat(distance, ", 0)")
    },
    to: {
      opacity: 1,
      transform: 'none'
    }
  };
}
/**
 * @public
 * @name makeFadeUp
 * @description make fade up object
 * @param distance
 * @returns {{from: {opacity: number, transform: string}, to: {opacity: number, transform: string}}}
 */


function makeFadeUp(_ref4) {
  var distance = _ref4.distance;
  return {
    from: {
      opacity: 0,
      transform: "translate3d(0, ".concat(distance, ", 0)")
    },
    to: {
      opacity: 1,
      transform: 'none'
    }
  };
}