"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeBlur = makeBlur;
exports.makeOpacity = makeOpacity;
exports.makeContrast = makeContrast;
exports.makeBrightness = makeBrightness;
exports.makeGrayscale = makeGrayscale;
exports.makeHueRotate = makeHueRotate;
exports.makeInvert = makeInvert;
exports.makeSaturate = makeSaturate;
exports.makeSepia = makeSepia;
exports.makeDropShadow = makeDropShadow;

/**
 * @public
 * @name makeBlur
 * @descrption make blur object
 * @param distance
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */
function makeBlur(_ref) {
  var distance = _ref.distance;
  return {
    '0%': {
      filter: 'blur(0px)'
    },
    '100%': {
      filter: "blur(".concat(distance, ")")
    }
  };
}
/**
 * @public
 * @name makeOpacity
 * @descrption make opacity object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeOpacity(_ref2) {
  var amplification = _ref2.amplification;
  return {
    '0%': {
      filter: 'opacity(0%)'
    },
    '100%': {
      filter: "opacity(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeContrast
 * @descrption make contrast object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeContrast(_ref3) {
  var amplification = _ref3.amplification;
  return {
    '0%': {
      filter: 'contrast(0%)'
    },
    '100%': {
      filter: "contrast(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeBrightness
 * @descrption make brightness object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeBrightness(_ref4) {
  var amplification = _ref4.amplification;
  return {
    '0%': {
      filter: 'brightness(0%)'
    },
    '100%': {
      filter: "brightness(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeGrayscale
 * @descrption make grayscale object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeGrayscale(_ref5) {
  var amplification = _ref5.amplification;
  return {
    '0%': {
      filter: 'grayscale(0%)'
    },
    '100%': {
      filter: "grayscale(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeHueRotate
 * @descrption make hue rotate object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeHueRotate(_ref6) {
  var rotation = _ref6.rotation;
  return {
    '0%': {
      filter: 'hue-rotate(0deg)'
    },
    '100%': {
      filter: "hue-rotate(".concat(rotation, ")")
    }
  };
}
/**
 * @public
 * @name makeInvert
 * @descrption make invert object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeInvert(_ref7) {
  var amplification = _ref7.amplification;
  return {
    '0%': {
      filter: 'invert(0%)'
    },
    '100%': {
      filter: "invert(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeSaturate
 * @descrption make saturate object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeSaturate(_ref8) {
  var amplification = _ref8.amplification;
  return {
    '0%': {
      filter: 'saturate(0%)'
    },
    '100%': {
      filter: "saturate(".concat(amplification * 8, "%)")
    }
  };
}
/**
 * @public
 * @name makeSepia
 * @descrption make sepia object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeSepia(_ref9) {
  var amplification = _ref9.amplification;
  return {
    '0%': {
      filter: 'sepia(0%)'
    },
    '100%': {
      filter: "sepia(".concat(amplification * 100, "%)")
    }
  };
}
/**
 * @public
 * @name makeDropShadow
 * @descrption make drop shadow object
 * @param amplification
 * @returns {{0%: {filter: string}, 100%: {filter: string}}}
 */


function makeDropShadow(_ref10) {
  var amplification = _ref10.amplification;
  return {
    '0%': {
      filter: 'drop-shadow(0px 0px 0px #000)'
    },
    '100%': {
      filter: "drop-shadow(".concat(amplification * 5, "px ").concat(amplification * 5, "px ").concat(amplification * 5, "px #000)")
    }
  };
}