"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeFlip = makeFlip;
exports.makeFlipX = makeFlipX;
exports.makeFlipY = makeFlipY;

var _typeEnums = require("../typeEnums");

/**
 * @public
 * @name makeFlip
 * @description make flip object
 * @param perspective
 * @returns {{from: {transform: string, animation-timing-function: string}, 40%: {transform: string, animation-timing-function: string}, 50%: {transform: string, animation-timing-function: string}, 80%: {transform: string, animation-timing-function: string}, to: {transform: string, animation-timing-function: string}}}
 */
function makeFlip(_ref) {
  var perspective = _ref.perspective;
  return {
    from: {
      transform: "perspective(".concat(perspective, ") rotate3d(0, 1, 0, -360deg)"),
      'animation-timing-function': 'ease-out'
    },
    '40%': {
      transform: "perspective(".concat(perspective, ") translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg)"),
      'animation-timing-function': 'ease-out'
    },
    '50%': {
      transform: "perspective(".concat(perspective, ") translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170px)"),
      'animation-timing-function': 'ease-in'
    },
    '80%': {
      transform: "perspective(".concat(perspective, ") scale3d(.90, .90, .90)"),
      'animation-timing-function': 'ease-in'
    },
    to: {
      transform: "perspective(".concat(perspective, ")"),
      'animation-timing-function': 'ease-in'
    }
  };
}

makeFlip.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeFlipX
 * @description make flipX object
 * @param perspective
 * @returns {{from: {transform: string, animation-timing-function: string}, 40%: {transform: string, animation-timing-function: string}, 50%: {transform: string, animation-timing-function: string}, 80%: {transform: string, animation-timing-function: string}, to: {transform: string, animation-timing-function: string}}}
 */

function makeFlipX(_ref2) {
  var perspective = _ref2.perspective;
  return {
    from: {
      transform: "perspective(".concat(perspective, ") rotate3d(1, 0, 0, 90deg)"),
      'animation-timing-function': 'ease-in',
      opacity: 0
    },
    '40%': {
      transform: "perspective(".concat(perspective, ") rotate3d(1, 0, 0, -20deg)"),
      'animation-timing-function': 'ease-in'
    },
    '60%': {
      transform: "perspective(".concat(perspective, ") rotate3d(1, 0, 0, 10deg)"),
      opacity: 1
    },
    '80%': {
      transform: "perspective(".concat(perspective, ") rotate3d(1, 0, 0, -5deg)")
    },
    to: {
      transform: "perspective(".concat(perspective, ")")
    }
  };
}

makeFlipX.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeFlipY
 * @description make flipY object
 * @param perspective
 * @returns {{from: {transform: string, animation-timing-function: string}, 40%: {transform: string, animation-timing-function: string}, 50%: {transform: string, animation-timing-function: string}, 80%: {transform: string, animation-timing-function: string}, to: {transform: string, animation-timing-function: string}}}
 */

function makeFlipY(_ref3) {
  var perspective = _ref3.perspective;
  return {
    from: {
      transform: "perspective(".concat(perspective, ") rotate3d(0, 1, 0, 90deg)"),
      'animation-timing-function': 'ease-in',
      opacity: 0
    },
    '40%': {
      transform: "perspective(".concat(perspective, ") rotate3d(0, 1, 0, -20deg)"),
      'animation-timing-function': 'ease-in'
    },
    '60%': {
      transform: "perspective(".concat(perspective, ") rotate3d(0, 1, 0, 10deg)"),
      opacity: 1
    },
    '80%': {
      transform: "perspective(".concat(perspective, ") rotate3d(0, 1, 0, -5deg)")
    },
    to: {
      transform: "perspective(".concat(perspective, ")")
    }
  };
}

makeFlipY.type = _typeEnums.TYPE_ROTATE;