"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeRotateIn = makeRotateIn;
exports.makeRotateLeft = makeRotateLeft;
exports.makeRotateRight = makeRotateRight;
exports.makeRotateUpLeft = makeRotateUpLeft;
exports.makeRotateUpRight = makeRotateUpRight;

var _typeEnums = require("../typeEnums");

/**
 * @public
 * @name makeRotateIn
 * @description make rotate in object
 * @param rotation
 * @returns {{from: {transform-origin: string, transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */
function makeRotateIn(_ref) {
  var rotation = _ref.rotation;
  return {
    from: {
      'transform-origin': 'center',
      transform: "rotate3d(0, 0, 1, -".concat(rotation, ")"),
      opacity: 0
    },
    to: {
      transform: 'none',
      opacity: 1
    }
  };
}

makeRotateIn.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRotateLeft
 * @description make rotate left object
 * @param rotation
 * @returns {{from: {transform-origin: string, transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */

function makeRotateLeft(_ref2) {
  var rotation = _ref2.rotation;
  return {
    from: {
      'transform-origin': 'left bottom',
      transform: "rotate3d(0, 0, 1, -".concat(rotation, ")"),
      opacity: 0
    },
    to: {
      'transform-origin': 'left bottom',
      transform: 'none',
      opacity: 1
    }
  };
}

makeRotateLeft.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRotateRight
 * @description make rotate right object
 * @param rotation
 * @returns {{from: {transform-origin: string, transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */

function makeRotateRight(_ref3) {
  var rotation = _ref3.rotation;
  return {
    from: {
      'transform-origin': 'right bottom',
      transform: "rotate3d(0, 0, 1, ".concat(rotation, ")"),
      opacity: 0
    },
    to: {
      'transform-origin': 'right bottom',
      transform: 'none',
      opacity: 1
    }
  };
}

makeRotateRight.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRotateUpLeft
 * @description make rotate up left object
 * @param rotation
 * @returns {{from: {transform-origin: string, transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */

function makeRotateUpLeft(_ref4) {
  var rotation = _ref4.rotation;
  return {
    from: {
      'transform-origin': 'left bottom',
      transform: "rotate3d(0, 0, 1, ".concat(rotation, ")"),
      opacity: 0
    },
    to: {
      'transform-origin': 'left bottom',
      transform: 'none',
      opacity: 1
    }
  };
}

makeRotateUpLeft.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRotateUpRight
 * @description make rotate up right object
 * @param rotation
 * @returns {{from: {transform-origin: string, transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */

function makeRotateUpRight(_ref5) {
  var rotation = _ref5.rotation;
  return {
    from: {
      'transform-origin': 'right bottom',
      transform: "rotate3d(0, 0, 1, -".concat(rotation, ")"),
      opacity: 0
    },
    to: {
      'transform-origin': 'right bottom',
      transform: 'none',
      opacity: 1
    }
  };
}

makeRotateUpRight.type = _typeEnums.TYPE_ROTATE;