"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeFlash = makeFlash;
exports.makeRollIn = makeRollIn;
exports.makeRollOut = makeRollOut;
exports.makeRubber = makeRubber;
exports.makeSwing = makeSwing;
exports.makeZoom = makeZoom;
exports.makeHinge = makeHinge;
exports.makePulse = makePulse;
exports.makeExpandUp = makeExpandUp;
exports.makeEntrance = makeEntrance;
exports.makeHatch = makeHatch;

var _typeEnums = require("../typeEnums");

/**
 * @public
 * @name makeFlash
 * @description flash object
 * @returns {{from: {opacity: number}, 25%: {opacity: number}, 50%: {opacity: number}, 75%: {opacity: number}, to: {opacity: number}}}
 */
function makeFlash() {
  return {
    from: {
      opacity: 1
    },
    '25%': {
      opacity: 0
    },
    '50%': {
      opacity: 1
    },
    '75%': {
      opacity: 0
    },
    to: {
      opacity: 1
    }
  };
}
/**
 * @public
 * @name makeRollIn
 * @description roll in object
 * @param distance
 * @param amplification
 * @returns {{from: {transform: string, opacity: number}, to: {transform: string, opacity: number}}}
 */


function makeRollIn(_ref) {
  var distance = _ref.distance,
      amplification = _ref.amplification;
  return {
    from: {
      transform: "translate3d(-".concat(distance, ", 0, 0) rotate3d(0, 0, 1, -").concat(amplification * 120, "deg)"),
      opacity: 0
    },
    to: {
      transform: 'none',
      opacity: 1
    }
  };
}

makeRollIn.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRollOut
 * @description roll out object
 * @param distance
 * @param amplification
 * @returns {{from: {opacity: number}, to: {transform: string, opacity: number}}}
 */

function makeRollOut(_ref2) {
  var distance = _ref2.distance,
      amplification = _ref2.amplification;
  return {
    from: {
      opacity: 1
    },
    to: {
      transform: "translate3d(".concat(distance, ", 0, 0) rotate3d(0, 0, 1, ").concat(amplification * 120, "deg)"),
      opacity: 0
    }
  };
}

makeRollOut.type = _typeEnums.TYPE_ROTATE;
/**
 * @public
 * @name makeRubber
 * @description Rubber object
 * @param amplification
 * @returns {{from: {transform: string}, 30%: {transform: string}, 40%: {transform: string}, 50%: {transform: string}, 65%: {transform: string}, 75%: {transform: string}, to: {transform: string}}}
 */

function makeRubber(_ref3) {
  var amplification = _ref3.amplification;
  return {
    from: {
      transform: 'scale3d(1, 1, 1)'
    },
    '30%': {
      transform: "scale3d(".concat(amplification * 1.25, ", ").concat(amplification * 0.75, ", ").concat(amplification * 1, ")")
    },
    '40%': {
      transform: "scale3d(".concat(amplification * 0.75, ", ").concat(amplification * 1.25, ", ").concat(amplification * 1, ")")
    },
    '50%': {
      transform: "scale3d(".concat(amplification * 1.15, ", ").concat(amplification * 0.85, ", ").concat(amplification * 1, ")")
    },
    '65%': {
      transform: "scale3d(".concat(amplification * 0.95, ", ").concat(amplification * 1.05, ", ").concat(amplification * 1, ")")
    },
    '75%': {
      transform: "scale3d(".concat(amplification * 1.05, ", ").concat(amplification * 0.95, ", ").concat(amplification * 1, ")")
    },
    to: {
      transform: 'scale3d(1, 1, 1)'
    }
  };
}
/**
 * @public
 * @name makeSwing
 * @description make swing object
 * @param amplification
 * @returns {{20%: {transform: string}, 40%: {transform: string}, 60%: {transform: string}, 80%: {transform: string}, to: {transform: string}}}
 */


function makeSwing(_ref4) {
  var amplification = _ref4.amplification;
  return {
    '20%': {
      transform: "rotate3d(0, 0, 1, ".concat(amplification * 15, "deg)")
    },
    '40%': {
      transform: "rotate3d(0, 0, 1, -".concat(amplification * 10, "deg)")
    },
    '60%': {
      transform: "rotate3d(0, 0, 1, ".concat(amplification * 5, "deg)")
    },
    '80%': {
      transform: "rotate3d(0, 0, 1, -".concat(amplification * 5, "deg)")
    },
    to: {
      transform: 'rotate3d(0, 0, 1, 0deg)'
    }
  };
}

makeSwing.type = _typeEnums.TYPE_ROTATE;
/**
 * @name makeZoom
 * @description make zoom object
 * @param amplification
 * @returns {{from: {opacity: number, transform: string}, to: {opacity: number}}}
 */

function makeZoom(_ref5) {
  var amplification = _ref5.amplification;
  return {
    from: {
      opacity: 0,
      transform: "scale3d(".concat(amplification * 0.4, ", ").concat(amplification * 0.4, ", ").concat(amplification * 0.4, ")")
    },
    to: {
      opacity: 1
    }
  };
}
/**
 * @public
 * @name makeHinge
 * @description make hinge object
 * @param amplification
 * @returns {{from: {transform-origin: string, animation-timing-function: string, opacity: number}, 20%, 40%: {transform-origin: string, transform: string, animation-timing-function: string, opacity: number}, 60%, 80%: {transform-origin: string, transform: string, animation-timing-function: string, opacity: number}, to: {transform: string, opacity: number}}}
 */


function makeHinge(_ref6) {
  var amplification = _ref6.amplification;
  return {
    from: {
      'transform-origin': 'top-left',
      'animation-timing-function': 'ease-in-out',
      opacity: 1
    },
    '20%, 40%': {
      'transform-origin': 'top-left',
      transform: "rotate(0, 0, 1, ".concat(amplification * 80, "deg)"),
      'animation-timing-function': 'ease-in-out',
      opacity: 1
    },
    '60%, 80%': {
      'transform-origin': 'top-left',
      transform: "rotate(0, 0, 1, ".concat(amplification * 20, "deg)"),
      'animation-timing-function': 'ease-in-out',
      opacity: 1
    },
    to: {
      transform: "translate3d(0, ".concat(amplification * 700, "px, 0)"),
      opacity: 0
    }
  };
}
/**
 * @public
 * @name makePulse
 * @description make pulse object
 * @param amplification
 * @returns {{from: {transform: string}, 50%: {transform: string}, to: {transform: string}}}
 */


function makePulse(_ref7) {
  var amplification = _ref7.amplification;
  return {
    from: {
      transform: 'scale3d(1, 1, 1)'
    },
    '50%': {
      transform: "scale3d(".concat(amplification * 1.4, ", ").concat(amplification * 1.4, ", ").concat(amplification * 1.4, ")")
    },
    to: {
      transform: 'scale3d(1, 1, 1)'
    }
  };
}
/**
 * @public
 * @name makeExpandUp
 * @description make expand up object
 * @param amplification
 * @returns {{0%: {transform: string}, 60%: {transform: string}, 75%: {transform: string}, 100%: {transform: string}}}
 */


function makeExpandUp(_ref8) {
  var amplification = _ref8.amplification;
  return {
    '0%': {
      transform: "translateY(100%) scale(".concat(amplification * 0.6, ") scaleY(").concat(amplification * 0.5, ")")
    },
    '60%': {
      transform: "translateY(-".concat(amplification * 7, "%) scaleY(").concat(amplification * 1.12, ")")
    },
    '75%': {
      transform: "translateY(".concat(amplification * 3, "%)")
    },
    '100%': {
      transform: "translateY(0%) scale(".concat(amplification * 1, ") scaleY(").concat(amplification * 1, ")")
    }
  };
}
/**
 * @public
 * @name makeEntrance
 * @description make entrance object
 * @param amplification
 * @returns {{0%: {transform: string, opacity: number}, 30%: {transform: string, opacity: number}, 45%: {transform: string, opacity: number}, 60%: {transform: string, opacity: number}, 75%: {transform: string, opacity: number}, 90%: {transform: string, opacity: number}, 100%: {transform: string, opacity: number}}}
 */


function makeEntrance(_ref9) {
  var amplification = _ref9.amplification;
  return {
    '0%': {
      transform: "scale(".concat(amplification * 0.3, ") rotate(").concat(amplification * 6, "deg) translateX(-").concat(amplification * 30, "%) translateY(").concat(amplification * 30, "%)"),
      opacity: 0.1
    },
    '30%': {
      transform: "scale(".concat(amplification * 1.03, ") rotate(-").concat(amplification * 2, "deg) translateX(").concat(amplification * 2, "%) translateY(-").concat(amplification * 2, "%)"),
      opacity: 1
    },
    '45%': {
      transform: "scale(".concat(amplification * 0.98, ")"),
      opacity: 1
    },
    '60%': {
      transform: "scale(".concat(amplification * 1.01, ")"),
      opacity: 1
    },
    '75%': {
      transform: "scale(".concat(amplification * 0.99, ")"),
      opacity: 1
    },
    '90%': {
      transform: "scale(".concat(amplification * 1.01, ")"),
      opacity: 1
    },
    '100%': {
      transform: 'scale(1)',
      opacity: 1
    }
  };
}
/**
 * @public
 * @name makeHatch
 * @description make hatch object
 * @param amplification
 * @returns {{0%: {transform: string}, 20%: {transform: string}, 35%: {transform: string}, 50%: {transform: string}, 65%: {transform: string}, 80%: {transform: string}, 100%: {transform: string}}}
 */


function makeHatch(_ref10) {
  var amplification = _ref10.amplification;
  return {
    '0%': {
      transform: 'scaleY(0.6)'
    },
    '20%': {
      transform: "rotate(-".concat(amplification * 2, "deg) scaleY(").concat(amplification * 1.05, ")")
    },
    '35%': {
      transform: "rotate(".concat(amplification * 2, "deg) scaleY(").concat(amplification, ")")
    },
    '50%': {
      transform: "rotate(-".concat(amplification, "deg)")
    },
    '65%': {
      transform: "rotate(".concat(amplification, "deg)")
    },
    '80%': {
      transform: "rotate(-".concat(amplification, "deg)")
    },
    '100%': {
      transform: 'none'
    }
  };
}